@@ -82,15 +82,16 @@ public class JAXRSCdiResourceExtension implements Extension {
     private boolean hasBus;
     private Bus bus;
 
-    private final Set< Bean< ? > > applicationBeans = new LinkedHashSet< Bean< ? > >();
-    private final List< Bean< ? > > serviceBeans = new ArrayList< Bean< ? > >();
-    private final List< Bean< ? > > providerBeans = new ArrayList< Bean< ? > >();
-    private final List< Bean< ? extends Feature > > featureBeans = new ArrayList< Bean< ? extends Feature > >();
+    private Set< Bean< ? > > applicationBeans = new LinkedHashSet< Bean< ? > >();
+    private Set< Bean< ? > > serviceBeans = new HashSet< Bean< ? > >();
+    private Set< Bean< ? > > providerBeans = new HashSet< Bean< ? > >();
+    private Set< Bean< ? extends Feature > > featureBeans = new HashSet< Bean< ? extends Feature > >();
+    private Set< Type > contextTypes = new LinkedHashSet<>();
+
     private final List< CreationalContext< ? > > disposableCreationalContexts =
         new ArrayList<>();
     private final List< Lifecycle > disposableLifecycles =
         new ArrayList<>();
-    private final Set< Type > contextTypes = new LinkedHashSet<>();
 
     private final Collection< String > existingStandardClasses = new HashSet<>();
 
@@ -98,7 +99,7 @@ public class JAXRSCdiResourceExtension implements Extension {
      * Holder of the classified resource classes, converted to appropriate instance
      * representations.
      */
-    private static class ClassifiedClasses {
+    private static final class ClassifiedClasses {
         private List< Object > providers = new ArrayList<>();
         private List< Feature > features = new ArrayList<>();
         private List<ResourceProvider> resourceProviders = new ArrayList<>();
@@ -262,6 +263,8 @@ public class JAXRSCdiResourceExtension implements Extension {
                 factory.init();
             }
         }
+
+        cleanStartupData();
     }
 
     public void injectBus(@Observes final AfterBeanDiscovery event, final BeanManager beanManager) {
@@ -295,6 +298,15 @@ public class JAXRSCdiResourceExtension implements Extension {
             t -> event.addBean(new ContextProducerBean(t, !existingStandardClasses.contains(t.getTypeName()))));
     }
 
+    private void cleanStartupData() { // enable gc
+        Stream.of(serviceBeans, providerBeans, featureBeans, applicationBeans, contextTypes).forEach(Collection::clear);
+        serviceBeans = null;
+        providerBeans = null;
+        featureBeans = null;
+        applicationBeans = null;
+        contextTypes = null;
+    }
+
     /**
      * Registers created CreationalContext instances for disposal
      */
@@ -496,7 +508,8 @@ public class JAXRSCdiResourceExtension implements Extension {
      * @return the references for all discovered CXF-specific features
      */
     private List< Feature > loadFeatures(final BeanManager beanManager, Collection<Class<?>> limitedClasses) {
-        final List< Feature > features = new ArrayList<>();
+        // Use set to account for singletons and application scoped beans
+        final Set< Feature > features = new LinkedHashSet<>();
 
         for (final Bean< ? extends Feature > bean: featureBeans) {
             if (limitedClasses.isEmpty() || limitedClasses.contains(bean.getBeanClass())) {
@@ -510,7 +523,7 @@ public class JAXRSCdiResourceExtension implements Extension {
             }
         }
 
-        return features;
+        return new ArrayList<>(features);
     }
 
     /**
