@@ -82,6 +82,9 @@ import org.apache.cxf.message.Message;
  *
  */
 public class WebClient extends AbstractClient {
+    // Use client configuration reference instead of sharing the instance directly
+    public static final String USE_CONFIGURATION_REFERENCE_WHEN_COPY = "use.configuration.reference.when.copy";
+
     private static final String REQUEST_CLASS = "request.class";
     private static final String REQUEST_TYPE = "request.type";
     private static final String REQUEST_ANNS = "request.annotations";
@@ -767,7 +770,7 @@ public class WebClient extends AbstractClient {
         if (path == null) {
             return back(true);
         }
-        back(path.startsWith("/") ? true : false);
+        back(path.startsWith("/"));
         return path(path);
     }
 
@@ -1062,7 +1065,7 @@ public class WebClient extends AbstractClient {
                                    inAnns, respClass, outType, exchange, invContext);
     }
     //CHECKSTYLE:OFF
-    protected Response doChainedInvocation(String httpMethod, //NOPMD
+    protected Response doChainedInvocation(String httpMethod,
                                            MultivaluedMap<String, String> headers,
                                            Object body,
                                            Class<?> requestClass,
@@ -1096,7 +1099,7 @@ public class WebClient extends AbstractClient {
     }
 
     //CHECKSTYLE:OFF
-    private Message finalizeMessage(String httpMethod, //NOPMD
+    private Message finalizeMessage(String httpMethod,
                                    MultivaluedMap<String, String> headers,
                                    Object body,
                                    Class<?> requestClass,
@@ -1233,7 +1236,21 @@ public class WebClient extends AbstractClient {
     static void copyProperties(Client toClient, Client fromClient) {
         AbstractClient newClient = toAbstractClient(toClient);
         AbstractClient oldClient = toAbstractClient(fromClient);
-        newClient.setConfiguration(oldClient.getConfiguration());
+        final ClientConfiguration oldCfg = oldClient.getConfiguration();
+
+        boolean useConfigurationReference = true;
+        if (oldCfg != null && oldCfg.getBus() != null) {
+            Object useConfigurationReferenceProp = oldCfg.getBus().getProperty(USE_CONFIGURATION_REFERENCE_WHEN_COPY);
+            if (useConfigurationReferenceProp != null) {
+                useConfigurationReference = PropertyUtils.isTrue(useConfigurationReferenceProp);
+            }
+        }
+
+        if (useConfigurationReference) {
+            newClient.setConfigurationReference(oldClient.getConfigurationReference());
+        } else {
+            newClient.setConfiguration(oldClient.getConfiguration());
+        }
     }
 
     private static AbstractClient toAbstractClient(Object client) {
