@@ -65,6 +65,7 @@ import static org.junit.Assert.fail;
 public class ClientAuthTest extends AbstractBusClientServerTestBase {
     static final String PORT = allocatePort(ClientAuthServer.class);
     static final String PORT2 = allocatePort(ClientAuthServer.class, 2);
+    static final String PORT3 = allocatePort(ClientAuthServer.class, 3);
 
     final Boolean async;
 
@@ -575,6 +576,74 @@ public class ClientAuthTest extends AbstractBusClientServerTestBase {
         ((java.io.Closeable)port).close();
     }
 
+    // Server directly trusts the client cert and uses TLSv1.3, no chunking
+    @org.junit.Test
+    public void testDirectTrustTls13LargeNoChunking() throws Exception {
+        SpringBusFactory bf = new SpringBusFactory();
+        URL busFile = ClientAuthTest.class.getResource("client-auth-tls-1.3.xml");
+
+        Bus bus = bf.createBus(busFile.toString());
+        BusFactory.setDefaultBus(bus);
+        BusFactory.setThreadDefaultBus(bus);
+
+        URL url = SOAPService.WSDL_LOCATION;
+        SOAPService service = new SOAPService(url, SOAPService.SERVICE);
+        assertNotNull("Service is null", service);
+        final Greeter port = service.getHttpsPort();
+        assertNotNull("Port is null", port);
+
+        updateAddressPort(port, PORT3);
+
+        // Enable Async
+        if (async) {
+            ((BindingProvider)port).getRequestContext().put("use.async.http.conduit", true);
+        }
+
+        Client client = ClientProxy.getClient(port);
+        HTTPConduit http = (HTTPConduit) client.getConduit();
+        http.getClient().setAllowChunking(false);
+
+        final String name = "Kitty ".repeat(500);
+        assertEquals(port.greetMe(name), "Hello " + name);
+
+        ((java.io.Closeable)port).close();
+        bus.shutdown(true);
+    }
+
+ // Server directly trusts the client cert and uses TLSv1.3, chunking
+    @org.junit.Test
+    public void testDirectTrustTls13LargeChunking() throws Exception {
+        SpringBusFactory bf = new SpringBusFactory();
+        URL busFile = ClientAuthTest.class.getResource("client-auth-tls-1.3.xml");
+
+        Bus bus = bf.createBus(busFile.toString());
+        BusFactory.setDefaultBus(bus);
+        BusFactory.setThreadDefaultBus(bus);
+
+        URL url = SOAPService.WSDL_LOCATION;
+        SOAPService service = new SOAPService(url, SOAPService.SERVICE);
+        assertNotNull("Service is null", service);
+        final Greeter port = service.getHttpsPort();
+        assertNotNull("Port is null", port);
+
+        updateAddressPort(port, PORT3);
+
+        // Enable Async
+        if (async) {
+            ((BindingProvider)port).getRequestContext().put("use.async.http.conduit", true);
+        }
+
+        Client client = ClientProxy.getClient(port);
+        HTTPConduit http = (HTTPConduit) client.getConduit();
+        http.getClient().setAllowChunking(true);
+
+        final String name = "Kitty ".repeat(500);
+        assertEquals(port.greetMe(name), "Hello " + name);
+
+        ((java.io.Closeable)port).close();
+        bus.shutdown(true);
+    }
+
     private static final class DisableCNCheckVerifier implements HostnameVerifier {
 
         @Override
